@@ -26,6 +26,7 @@
 
 #include "grd-egl-thread.h"
 #include "grd-settings-handover.h"
+#include "grd-settings-headless.h"
 #include "grd-settings-system.h"
 #include "grd-settings-user.h"
 
@@ -153,8 +154,10 @@ grd_context_new (GrdRuntimeMode   runtime_mode,
   switch (runtime_mode)
     {
     case GRD_RUNTIME_MODE_SCREEN_SHARE:
+      context->settings = GRD_SETTINGS (grd_settings_user_new ());
+      break;
     case GRD_RUNTIME_MODE_HEADLESS:
-      context->settings = GRD_SETTINGS (grd_settings_user_new (runtime_mode));
+      context->settings = GRD_SETTINGS (grd_settings_headless_new ());
       break;
     case GRD_RUNTIME_MODE_SYSTEM:
       context->settings = GRD_SETTINGS (grd_settings_system_new ());
