@@ -27,7 +27,10 @@
 static const GDebugKey grd_debug_keys[] = {
   { "vnc", GRD_DEBUG_VNC },
   { "tpm", GRD_DEBUG_TPM },
-  { "rdp-legacy-graphics", GRD_DEBUG_RDP_LEGACY_GRAPHICS },
+  { "vk-validation", GRD_DEBUG_VK_VALIDATION },
+  { "vk-times", GRD_DEBUG_VK_TIMES },
+  { "va-times", GRD_DEBUG_VA_TIMES },
+  { "vkva-renderer", GRD_DEBUG_VKVA },
 };
 
 static GrdDebugFlags debug_flags;
