@@ -26,6 +26,10 @@
 #include <epoxy/gl.h>
 #include <gio/gio.h>
 
+#ifndef EGL_DRM_RENDER_NODE_FILE_EXT
+#define EGL_DRM_RENDER_NODE_FILE_EXT 0x3377
+#endif
+
 struct _GrdEglThread
 {
   GThread *thread;
@@ -48,6 +52,8 @@ struct _GrdEglThread
     EGLDisplay egl_display;
     EGLContext egl_context;
 
+    const char *drm_render_node;
+
     GSource *egl_thread_source;
   } impl;
 };
@@ -127,14 +133,6 @@ typedef struct _GrdEglTaskDownload
 {
   GrdEglTask base;
 
-  GLuint pbo;
-  uint32_t pbo_height;
-  uint32_t pbo_stride;
-
-  GrdEglThreadImportIface iface;
-  gpointer import_user_data;
-  GDestroyNotify import_destroy_notify;
-
   uint8_t *dst_data;
   int dst_row_width;
 
@@ -323,6 +321,52 @@ query_format_modifiers (GrdEglThread  *egl_thread,
   return TRUE;
 }
 
+static gboolean
+lookup_drm_render_node (GrdEglThread  *egl_thread,
+                        EGLDisplay     egl_display,
+                        GError       **error)
+{
+  EGLAttrib egl_attrib = 0;
+  EGLDeviceEXT egl_device;
+  const char *egl_extensions;
+
+  if (!eglQueryDisplayAttribEXT (egl_display, EGL_DEVICE_EXT, &egl_attrib))
+    {
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+                   "Failed to retrieve EGL device");
+      return FALSE;
+    }
+  g_assert (egl_attrib);
+
+  egl_device = (EGLDeviceEXT) egl_attrib;
+
+  egl_extensions = eglQueryDeviceStringEXT (egl_device, EGL_EXTENSIONS);
+  if (!egl_extensions)
+    {
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+                   "Failed to retrieve EGL device extensions");
+      return FALSE;
+    }
+
+  if (!strstr (egl_extensions, "EGL_EXT_device_drm_render_node"))
+    {
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+                   "Missing extension 'EGL_EXT_device_drm_render_node'");
+      return FALSE;
+    }
+
+  egl_thread->impl.drm_render_node =
+    eglQueryDeviceStringEXT (egl_device, EGL_DRM_RENDER_NODE_FILE_EXT);
+  if (!egl_thread->impl.drm_render_node)
+    {
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+                   "Failed to retrieve EGL device extensions");
+      return FALSE;
+    }
+
+  return TRUE;
+}
+
 static gboolean
 initialize_egl_context (GrdEglThread  *egl_thread,
                         EGLenum        egl_platform,
@@ -433,6 +477,17 @@ initialize_egl_context (GrdEglThread  *egl_thread,
       return FALSE;
     }
 
+  if (!lookup_drm_render_node (egl_thread, egl_display, error))
+    {
+      eglMakeCurrent (egl_display, EGL_NO_SURFACE, EGL_NO_SURFACE,
+                      EGL_NO_CONTEXT);
+      eglDestroyContext (egl_display, egl_context);
+      eglTerminate (egl_display);
+      return FALSE;
+    }
+
+  g_debug ("[EGL] DRM render node path: %s", egl_thread->impl.drm_render_node);
+
   egl_thread->impl.egl_display = egl_display;
   egl_thread->impl.egl_context = egl_context;
 
@@ -485,9 +540,6 @@ grd_egl_task_download_free (GrdEglTask *task_base)
   g_free (task->offsets);
   g_free (task->modifiers);
 
-  if (task->import_destroy_notify)
-    task->import_destroy_notify (task->import_user_data);
-
   grd_egl_task_free (task_base);
 }
 
@@ -699,6 +751,12 @@ grd_egl_thread_free (GrdEglThread *egl_thread)
   g_free (egl_thread);
 }
 
+const char *
+grd_egl_thread_get_drm_render_node (GrdEglThread *egl_thread)
+{
+  return egl_thread->impl.drm_render_node;
+}
+
 void *
 grd_egl_thread_acquire_slot (GrdEglThread *egl_thread)
 {
@@ -868,31 +926,9 @@ download_in_impl (gpointer data,
   GrdEglTaskDownload *task = user_data;
   EGLImageKHR egl_image = EGL_NO_IMAGE;
   gboolean success = FALSE;
-  uint32_t buffer_size;
   GLuint tex = 0;
   GLuint fbo = 0;
 
-  buffer_size = task->pbo_stride * task->pbo_height * sizeof (uint8_t);
-  if (task->iface.allocate && !task->pbo)
-    {
-      GLuint pbo = 0;
-
-      glGenBuffers (1, &pbo);
-      glBindBuffer (GL_PIXEL_PACK_BUFFER, pbo);
-      glBufferData (GL_PIXEL_PACK_BUFFER, buffer_size, NULL, GL_DYNAMIC_DRAW);
-      glBindBuffer (GL_PIXEL_PACK_BUFFER, 0);
-
-      if (!task->iface.allocate (task->import_user_data, pbo))
-        {
-          g_warning ("[EGL Thread] Failed to allocate GL resources");
-          glDeleteBuffers (1, &pbo);
-          goto out;
-        }
-
-      g_debug ("[EGL Thread] Allocating GL resources was successful");
-      task->pbo = pbo;
-    }
-
   egl_image =
     create_dmabuf_image (egl_thread,
                          task->width,
@@ -910,27 +946,6 @@ download_in_impl (gpointer data,
                        task->dst_data ? &fbo : NULL))
     goto out;
 
-  if (task->iface.realize)
-    {
-      GLenum error;
-
-      glBindBuffer (GL_PIXEL_PACK_BUFFER, task->pbo);
-      glBufferData (GL_PIXEL_PACK_BUFFER, buffer_size, NULL, GL_DYNAMIC_DRAW);
-      glReadPixels (0, 0, task->width, task->height,
-                    GL_BGRA, GL_UNSIGNED_BYTE, NULL);
-      error = glGetError ();
-      if (error != GL_NO_ERROR)
-        {
-          g_warning ("[EGL Thread] Failed to update buffer data: %u", error);
-          goto out;
-        }
-
-      glBindBuffer (GL_PIXEL_PACK_BUFFER, 0);
-
-      if (!task->iface.realize (task->import_user_data))
-        goto out;
-    }
-
   if (task->dst_data)
     read_pixels (task->dst_data, task->width, task->height);
 
@@ -1095,12 +1110,6 @@ push_replaceable_task (GrdEglThread     *egl_thread,
 void
 grd_egl_thread_download (GrdEglThread                  *egl_thread,
                          GrdEglThreadSlot               slot,
-                         uint32_t                       pbo,
-                         uint32_t                       pbo_height,
-                         uint32_t                       pbo_stride,
-                         const GrdEglThreadImportIface *iface,
-                         gpointer                       import_user_data,
-                         GDestroyNotify                 import_destroy_notify,
                          uint8_t                       *dst_data,
                          int                            dst_row_width,
                          uint32_t                       format,
@@ -1119,14 +1128,6 @@ grd_egl_thread_download (GrdEglThread                  *egl_thread,
 
   task = g_new0 (GrdEglTaskDownload, 1);
 
-  task->pbo = pbo;
-  task->pbo_height = pbo_height;
-  task->pbo_stride = pbo_stride;
-
-  task->iface = iface ? *iface : (GrdEglThreadImportIface) {};
-  task->import_user_data = import_user_data;
-  task->import_destroy_notify = import_destroy_notify;
-
   task->dst_data = dst_data;
   task->dst_row_width = dst_row_width;
 
