@@ -17,8 +17,7 @@
  * 02111-1307, USA.
  */
 
-#ifndef GRD_RDP_EVENT_QUEUE_H
-#define GRD_RDP_EVENT_QUEUE_H
+#pragma once
 
 #include <glib-object.h>
 #include <stdint.h>
@@ -42,9 +41,13 @@ void grd_rdp_event_queue_add_input_event_keyboard_keysym (GrdRdpEventQueue *rdp_
                                                           uint32_t          keysym,
                                                           GrdKeyState       state);
 
-void grd_rdp_event_queue_add_input_event_pointer_motion_abs (GrdRdpEventQueue               *rdp_event_queue,
-                                                             GrdStream                      *stream,
-                                                             const GrdEventPointerMotionAbs *motion_abs);
+void grd_rdp_event_queue_add_input_event_pointer_motion (GrdRdpEventQueue *rdp_event_queue,
+                                                         double            dx,
+                                                         double            dy);
+
+void grd_rdp_event_queue_add_input_event_pointer_motion_abs (GrdRdpEventQueue        *rdp_event_queue,
+                                                             GrdStream               *stream,
+                                                             const GrdEventMotionAbs *motion_abs);
 
 void grd_rdp_event_queue_add_input_event_pointer_button (GrdRdpEventQueue *rdp_event_queue,
                                                          int32_t           button,
@@ -65,4 +68,4 @@ void grd_rdp_event_queue_add_synchronization_event (GrdRdpEventQueue *rdp_event_
                                                     gboolean          caps_lock_state,
                                                     gboolean          num_lock_state);
 
-#endif /* GRD_RDP_EVENT_QUEUE_H */
+void grd_rdp_event_queue_flush_synchronization (GrdRdpEventQueue *rdp_event_queue);
