@@ -21,11 +21,14 @@
 
 #include "grd-rdp-layout-manager.h"
 
+#include "grd-context.h"
+#include "grd-rdp-cursor-renderer.h"
 #include "grd-rdp-pipewire-stream.h"
 #include "grd-rdp-renderer.h"
 #include "grd-rdp-session-metrics.h"
 #include "grd-rdp-surface.h"
 #include "grd-session-rdp.h"
+#include "grd-settings-user.h"
 #include "grd-stream.h"
 
 #define LAYOUT_RECREATION_TIMEOUT_MS 50
@@ -74,6 +77,8 @@ struct _GrdRdpLayoutManager
   GrdHwAccelNvidia *hwaccel_nvidia;
   rdpContext *rdp_context;
 
+  GrdRdpScreenShareMode screen_share_mode;
+
   GSource *layout_update_source;
   GSource *preparation_source;
   GHashTable *surface_table;
@@ -398,9 +403,8 @@ on_pipewire_stream_video_resized (GrdRdpPipeWireStream *pipewire_stream,
       (virtual_monitor->width != width || virtual_monitor->height != height))
     {
       g_warning ("[RDP] Layout manager: Unexpected video size change of PipeWire "
-                 "stream (Expected: %ux%u, Got: %ux%u). Terminating session",
+                 "stream (Expected: %ux%u, Got: %ux%u). Ignoring resize event...",
                  virtual_monitor->width, virtual_monitor->height, width, height);
-      transition_to_state (layout_manager, UPDATE_STATE_FATAL_ERROR);
       return;
     }
 
@@ -518,15 +522,43 @@ grd_rdp_layout_manager_on_stream_created (GrdRdpStreamOwner *stream_owner,
                     layout_manager);
 }
 
+static gboolean
+is_extending_physical_desktop (GrdRdpLayoutManager *layout_manager)
+{
+  GrdSession *session = GRD_SESSION (layout_manager->session_rdp);
+  GrdContext *context = grd_session_get_context (session);
+  GrdSettings *settings = grd_context_get_settings (context);
+
+  return GRD_IS_SETTINGS_USER (settings) &&
+         layout_manager->screen_share_mode == GRD_RDP_SCREEN_SHARE_MODE_EXTEND;
+}
+
+static void
+hide_default_cursor (GrdRdpLayoutManager *layout_manager)
+{
+  GrdRdpCursorUpdate *cursor_update;
+
+  cursor_update = g_new0 (GrdRdpCursorUpdate, 1);
+  cursor_update->update_type = GRD_RDP_CURSOR_UPDATE_TYPE_HIDDEN;
+
+  grd_rdp_cursor_renderer_submit_cursor_update (layout_manager->cursor_renderer,
+                                                cursor_update);
+}
+
 void
-grd_rdp_layout_manager_notify_session_started (GrdRdpLayoutManager  *layout_manager,
-                                               GrdRdpCursorRenderer *cursor_renderer,
-                                               rdpContext           *rdp_context)
+grd_rdp_layout_manager_notify_session_started (GrdRdpLayoutManager   *layout_manager,
+                                               GrdRdpCursorRenderer  *cursor_renderer,
+                                               rdpContext            *rdp_context,
+                                               GrdRdpScreenShareMode  screen_share_mode)
 {
   layout_manager->cursor_renderer = cursor_renderer;
   layout_manager->rdp_context = rdp_context;
+  layout_manager->screen_share_mode = screen_share_mode;
   layout_manager->session_started = TRUE;
 
+  if (is_extending_physical_desktop (layout_manager))
+    hide_default_cursor (layout_manager);
+
   g_source_set_ready_time (layout_manager->layout_update_source, 0);
 }
 
@@ -548,11 +580,11 @@ grd_rdp_layout_manager_submit_new_monitor_config (GrdRdpLayoutManager *layout_ma
 }
 
 gboolean
-grd_rdp_layout_manager_transform_position (GrdRdpLayoutManager       *layout_manager,
-                                           uint32_t                   x,
-                                           uint32_t                   y,
-                                           GrdStream                **stream,
-                                           GrdEventPointerMotionAbs  *motion_abs)
+grd_rdp_layout_manager_transform_position (GrdRdpLayoutManager  *layout_manager,
+                                           uint32_t              x,
+                                           uint32_t              y,
+                                           GrdStream           **stream,
+                                           GrdEventMotionAbs    *motion_abs)
 {
   g_autoptr (GMutexLocker) locker = NULL;
   SurfaceContext *surface_context = NULL;
@@ -828,9 +860,14 @@ create_stream (SurfaceContext *surface_context,
 
   if (surface_context->virtual_monitor)
     {
-      grd_session_record_virtual (session, stream_id,
-                                  GRD_SCREEN_CAST_CURSOR_MODE_METADATA,
-                                  TRUE);
+      GrdScreenCastCursorMode cursor_mode;
+
+      if (is_extending_physical_desktop (layout_manager))
+        cursor_mode = GRD_SCREEN_CAST_CURSOR_MODE_EMBEDDED;
+      else
+        cursor_mode = GRD_SCREEN_CAST_CURSOR_MODE_METADATA;
+
+      grd_session_record_virtual (session, stream_id, cursor_mode, TRUE);
     }
   else
     {
