@@ -18,8 +18,7 @@
  *
  */
 
-#ifndef GRD_STREAM_H
-#define GRD_STREAM_H
+#pragma once
 
 #include <glib-object.h>
 #include <stdint.h>
@@ -49,5 +48,3 @@ uint32_t grd_stream_get_pipewire_node_id (GrdStream *stream);
 const char * grd_stream_get_mapping_id (GrdStream *stream);
 
 void grd_stream_disconnect_proxy_signals (GrdStream *stream);
-
-#endif /* GRD_STREAM_H */
