@@ -20,8 +20,7 @@
  *     Jonas Ådahl <jadahl@gmail.com>
  */
 
-#ifndef GRD_TYPES_H
-#define GRD_TYPES_H
+#pragma once
 
 typedef struct _GrdAVCFrameInfo GrdAVCFrameInfo;
 typedef struct _GrdBitstream GrdBitstream;
@@ -38,9 +37,7 @@ typedef struct _GrdHwAccelVaapi GrdHwAccelVaapi;
 typedef struct _GrdHwAccelVulkan GrdHwAccelVulkan;
 typedef struct _GrdImageView GrdImageView;
 typedef struct _GrdLocalBuffer GrdLocalBuffer;
-typedef struct _GrdRdpAudioInput GrdRdpAudioInput;
 typedef struct _GrdRdpAudioOutputStream GrdRdpAudioOutputStream;
-typedef struct _GrdRdpAudioPlayback GrdRdpAudioPlayback;
 typedef struct _GrdRdpAudioVolumeData GrdRdpAudioVolumeData;
 typedef struct _GrdRdpBuffer GrdRdpBuffer;
 typedef struct _GrdRdpBufferInfo GrdRdpBufferInfo;
@@ -48,8 +45,13 @@ typedef struct _GrdRdpBufferPool GrdRdpBufferPool;
 typedef struct _GrdRdpConnectTimeAutodetection GrdRdpConnectTimeAutodetection;
 typedef struct _GrdRdpCursorRenderer GrdRdpCursorRenderer;
 typedef struct _GrdRdpDamageDetector GrdRdpDamageDetector;
-typedef struct _GrdRdpDisplayControl GrdRdpDisplayControl;
-typedef struct _GrdRdpDvc GrdRdpDvc;
+typedef struct _GrdRdpDvcAudioInput GrdRdpDvcAudioInput;
+typedef struct _GrdRdpDvcAudioPlayback GrdRdpDvcAudioPlayback;
+typedef struct _GrdRdpDvcDisplayControl GrdRdpDvcDisplayControl;
+typedef struct _GrdRdpDvcGraphicsPipeline GrdRdpDvcGraphicsPipeline;
+typedef struct _GrdRdpDvcHandler GrdRdpDvcHandler;
+typedef struct _GrdRdpDvcInput GrdRdpDvcInput;
+typedef struct _GrdRdpDvcTelemetry GrdRdpDvcTelemetry;
 typedef struct _GrdRdpEventQueue GrdRdpEventQueue;
 typedef struct _GrdRdpFrame GrdRdpFrame;
 typedef struct _GrdRdpFrameStats GrdRdpFrameStats;
@@ -57,7 +59,6 @@ typedef struct _GrdRdpGfxFrameController GrdRdpGfxFrameController;
 typedef struct _GrdRdpGfxFrameLog GrdRdpGfxFrameLog;
 typedef struct _GrdRdpGfxFramerateLog GrdRdpGfxFramerateLog;
 typedef struct _GrdRdpGfxSurface GrdRdpGfxSurface;
-typedef struct _GrdRdpGraphicsPipeline GrdRdpGraphicsPipeline;
 typedef struct _GrdRdpLayoutManager GrdRdpLayoutManager;
 typedef struct _GrdRdpLegacyBuffer GrdRdpLegacyBuffer;
 typedef struct _GrdRdpNetworkAutodetection GrdRdpNetworkAutodetection;
@@ -72,12 +73,12 @@ typedef struct _GrdRdpStreamOwner GrdRdpStreamOwner;
 typedef struct _GrdRdpSurface GrdRdpSurface;
 typedef struct _GrdRdpSurfaceRenderer GrdRdpSurfaceRenderer;
 typedef struct _GrdRdpSwEncoderCa GrdRdpSwEncoderCa;
-typedef struct _GrdRdpTelemetry GrdRdpTelemetry;
 typedef struct _GrdRdpViewCreator GrdRdpViewCreator;
 typedef struct _GrdSession GrdSession;
 typedef struct _GrdSessionRdp GrdSessionRdp;
 typedef struct _GrdSessionVnc GrdSessionVnc;
 typedef struct _GrdStream GrdStream;
+typedef struct _GrdTouchContact GrdTouchContact;
 typedef struct _GrdVkBuffer GrdVkBuffer;
 typedef struct _GrdVkDevice GrdVkDevice;
 typedef struct _GrdVkImage GrdVkImage;
@@ -91,5 +92,3 @@ typedef enum _GrdPixelFormat
 {
   GRD_PIXEL_FORMAT_RGBA8888,
 } GrdPixelFormat;
-
-#endif /* GRD_TYPES_H */
