@@ -20,8 +20,7 @@
  *     Jonas Ådahl <jadahl@gmail.com>
  */
 
-#ifndef GRD_VNC_SERVER_H
-#define GRD_VNC_SERVER_H
+#pragma once
 
 #include <gio/gio.h>
 #include <glib-object.h>
@@ -32,12 +31,12 @@
 G_DECLARE_FINAL_TYPE (GrdVncServer,
                       grd_vnc_server,
                       GRD, VNC_SERVER,
-                      GSocketService);
+                      GSocketService)
 
 GrdContext *grd_vnc_server_get_context (GrdVncServer *vnc_server);
 
 gboolean grd_vnc_server_start (GrdVncServer *vnc_server, GError **error);
 
-GrdVncServer *grd_vnc_server_new (GrdContext *context);
+void grd_vnc_server_stop (GrdVncServer *vnc_server);
 
-#endif /* GRD_VNC_SERVER_H */
+GrdVncServer *grd_vnc_server_new (GrdContext *context);
